==> stepfunctions-1.175.0-sources.jar: software/amazon/awscdk/services/stepfunctions/Context.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * (deprecated) Extract a field from the State Machine Context data.
 * <p>
 * @see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#wait-token-contextobject">https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#wait-token-contextobject</a>
 * @deprecated replaced by `JsonPath`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-28T18:14:38.854Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.Context")
public class Context extends software.amazon.jsii.JsiiObject {

    protected Context(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Context(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (deprecated) Instead of using a literal number, get the value from a JSON path.
     * <p>
     * @param path This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.Number numberAt(final @org.jetbrains.annotations.NotNull java.lang.String path) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.stepfunctions.Context.class, "numberAt", software.amazon.jsii.NativeType.forClass(java.lang.Number.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
    }

    /**
     * (deprecated) Instead of using a literal string, get the value from a JSON path.
     * <p>
     * @param path This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.String stringAt(final @org.jetbrains.annotations.NotNull java.lang.String path) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.stepfunctions.Context.class, "stringAt", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
    }

    /**
     * (deprecated) Use the entire context data structure.
     * <p>
     * Will be an object at invocation time, but is represented in the CDK
     * application as a string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.String getEntireContext() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.Context.class, "entireContext", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (deprecated) Return the Task Token field.
     * <p>
     * External actions will need this token to report step completion
     * back to StepFunctions using the <code>SendTaskSuccess</code> or <code>SendTaskFailure</code>
     * calls.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.String getTaskToken() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.Context.class, "taskToken", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> stepfunctions-1.204.0-sources.jar: software/amazon/awscdk/services/stepfunctions/Context.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * (deprecated) Extract a field from the State Machine Context data.
 * <p>
 * @see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#wait-token-contextobject">https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#wait-token-contextobject</a>
 * @deprecated replaced by <code>JsonPath</code>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:39.900Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.Context")
public class Context extends software.amazon.jsii.JsiiObject {

    protected Context(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Context(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (deprecated) Instead of using a literal number, get the value from a JSON path.
     * <p>
     * @param path This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.Number numberAt(final @org.jetbrains.annotations.NotNull java.lang.String path) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.stepfunctions.Context.class, "numberAt", software.amazon.jsii.NativeType.forClass(java.lang.Number.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
    }

    /**
     * (deprecated) Instead of using a literal string, get the value from a JSON path.
     * <p>
     * @param path This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.String stringAt(final @org.jetbrains.annotations.NotNull java.lang.String path) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.stepfunctions.Context.class, "stringAt", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
    }

    /**
     * (deprecated) Use the entire context data structure.
     * <p>
     * Will be an object at invocation time, but is represented in the CDK
     * application as a string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.String getEntireContext() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.Context.class, "entireContext", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (deprecated) Return the Task Token field.
     * <p>
     * External actions will need this token to report step completion
     * back to StepFunctions using the <code>SendTaskSuccess</code> or <code>SendTaskFailure</code>
     * calls.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static @org.jetbrains.annotations.NotNull java.lang.String getTaskToken() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.Context.class, "taskToken", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
